# Generated by Django 4.2.1 on 2023-11-13 02:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('geolocation', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserBase',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('email', models.EmailField(max_length=254, unique=True, verbose_name='email')),
                ('email_sender', models.EmailField(max_length=254, null=True, verbose_name='email')),
                ('username', models.CharField(max_length=150, unique=True, verbose_name='username')),
                ('full_name', models.CharField(max_length=150, verbose_name='Full Name')),
                ('about', models.TextField(blank=True, max_length=500, verbose_name='about')),
                ('cloud_id', models.CharField(max_length=150, null=True, unique=True)),
                ('image', models.ImageField(blank=True, null=True, upload_to='profile/', verbose_name='Avatar')),
                ('phone_number', models.CharField(default='No Phone', max_length=15)),
                ('zip', models.CharField(blank=True, max_length=50, null=True)),
                ('address', models.CharField(max_length=150, verbose_name='Address')),
                ('meta_token', models.CharField(default='no_token', max_length=1000)),
                ('meta_status', models.CharField(default='not_logged_in', max_length=50)),
                ('meta_id', models.CharField(default='noID', max_length=150)),
                ('is_active', models.BooleanField(default=False, help_text='Control of user status', verbose_name='Activation')),
                ('is_staff', models.BooleanField(default=False)),
                ('is_subscribed', models.BooleanField(default=False)),
                ('is_business', models.BooleanField(default=False)),
                ('is_suspended', models.BooleanField(default=False)),
                ('yearly_subscriber', models.BooleanField(default=False)),
                ('cloud_services', models.BooleanField(default=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('newsletter', models.BooleanField(default=False, help_text='If you accept, we will keep you informed of all our promotions and offers.')),
                ('city_profile', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.city')),
                ('country_profile', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='geolocation.country', verbose_name='Country')),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='user_set', related_query_name='user', to='auth.group', verbose_name='groups')),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='user_set', related_query_name='user', to='auth.permission', verbose_name='user permissions')),
            ],
            options={
                'verbose_name': 'Accounts',
                'verbose_name_plural': 'Accounts',
            },
        ),
    ]



from django.views.decorators.csrf import csrf_exempt
import stripe, requests
from django.http import JsonResponse
from django.conf import settings
from .views import orderGenerator


@csrf_exempt
def stripePayment(request):
    payload = request.body
    sig_header = request.META['HTTP_STRIPE_SIGNATURE']
    event = None

    try:
        stripe.api_key = settings.STRIPE_SECRET_KEY
        event = stripe.Webhook.construct_event(
        payload, sig_header, settings.WEBHOOK_SECRET
        )

    except ValueError as e:
        # Invalid payload
        raise e
    except stripe.error.SignatureVerificationError as e:
        # Invalid signature
        raise e
    
    # Passed signature verification
    if event['type'] == 'charge.failed':
      print('payment failed')
    elif event['type'] == 'charge.dispute.created':
      print('dispute payment')
    elif event['type'] == 'payment_intent.created':
      print('payment intent')
    elif event['type'] == 'payment_intent.succeeded':
        data = event.data.object.id
        orderGenerator(data)
        # ... handle other event types
    return JsonResponse({'success': True})





from django.contrib.auth import login, logout, authenticate
from django.contrib.auth.forms import PasswordResetForm
from django.conf import settings
from django.core.mail import send_mail, EmailMultiAlternatives
from django.utils.html import strip_tags
from django.utils import timezone
from django.http.response import JsonResponse
from django.shortcuts import redirect, render
from django.contrib import messages
from accounts.forms import LoginForm
from .forms import PwdResetForm, RegistrationForm, UserEditForm, CleanForm, UserLoginForm, PwdResetConfirmForm
from .models import UserBase
from stela_control.models import DataEmail
from django.utils.http import urlsafe_base64_encode, urlsafe_base64_decode
from django.utils.encoding import force_bytes, force_str
from .token import account_activation_token
from django.template.loader import render_to_string
from django.contrib.sites.shortcuts import get_current_site
from django.contrib.auth.decorators import login_required
from django.utils.translation import gettext_lazy as _
import re

# Create your views here.
@login_required
def profile_view(request):
    return render(request, 'link-zone/user/profile/profile.html')

def confirm_view(request):

    return render(request, 'accounts/registration/confirmation_email.html')

def account_register(request):
    date = timezone.now()
    if request.method == 'POST':
        registerForm = RegistrationForm(request.POST)
        if registerForm.is_valid():
            user = registerForm.save(commit=False)
            user.email = registerForm.cleaned_data['email']
            user.set_password(registerForm.cleaned_data['password'])
            user.is_active = False
            user.save()
            if UserBase.objects.filter(newsletter=True):
                 data = DataEmail.objects.filter(email=user.email)
                 if data.exists():
                    pass
                 else:
                    DataEmail.objects.create(
                         email = user.email,
                         date = date
                 ) 
            current_site = get_current_site(request)
            subject = _('Activate your account')
            html_content = render_to_string('emails/registration/confirmation.html', {
                        'user': user,           
                        'domain': current_site.domain,
                        'uid': urlsafe_base64_encode(force_bytes(user.pk)),
                        'token': account_activation_token.make_token(user),
                        })
            text_content = strip_tags(html_content)

            email = EmailMultiAlternatives(
                subject,
                text_content,
                settings.DEFAULT_EMAIL,
                [user.email]
            )
            email.attach_alternative(html_content, "text/html")
            email.send()

            subject = _('New User On Your Site')
            html_content = render_to_string('emails/registration/alert.html', {
                        'user': user,           
                        'domain': current_site.domain,
                        'uid': urlsafe_base64_encode(force_bytes(user.pk)),
                        'token': account_activation_token.make_token(user),
                        })
            text_content = strip_tags(html_content)

            email = EmailMultiAlternatives(
                subject,
                text_content,
                settings.STELA_EMAIL,
                [settings.DEFAULT_EMAIL]
            )
            email.attach_alternative(html_content, "text/html")
            email.send()
            
            return redirect('accounts:confirm')

    else:
        registerForm = RegistrationForm()
    return render(request, 'accounts/registration/register.html',{'form':registerForm})

def request(request):
    action = request.POST.get('action')
    print(action)
    
    if action == "checkEmail":
        pattern = re.compile(r'^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$')
        email = request.POST.get("user_input")
        if UserBase.objects.filter(email=email).exists():
            response = JsonResponse({'error': _('email not available')})
        elif not pattern.match(email):
            response = JsonResponse({'error': _('Invalid email')})
        else:
            response = JsonResponse({'success': _('email available')})
        return response

    if action == "checkUsername":
        username = request.POST.get("user_input")
        if UserBase.objects.filter(username=username).exists():
            response = JsonResponse({'error': _('username not available')})
            
        elif not re.match(r'^[a-z0-9_]+$', username):
            response = JsonResponse({'error': _('invalid username only lower case, numbers and (_) accepted')})
        
        else:
            response = JsonResponse({'success': _('username available')})
        
        return response
        
    if action == "checkPassword":
        password = request.POST.get("password")
        
        if len(password) < 8:
            response = JsonResponse({'error': _('Password must be at least 8 characters long')})
        
        elif not re.match(r'^[a-zA-Z0-9*.$_]+$', password):
            response = JsonResponse({'error': _('Password must contain only alphanumeric and special characters (a-zA-Z0-9*$_.)')})
        
        elif password.isalpha():
            response = JsonResponse({'error': _('Password must contain at least one number')})
            
        else:
            response = JsonResponse({'success': _('Password is valid')})

        return response

    if action == "matchPassword":
        password1 = request.POST.get("password1")
        password2 = request.POST.get("password2")

        if password1 != password2:
            response = JsonResponse({'error': _('Password dismatch.')})
        else:
            response = JsonResponse({'success': _('Password match')})
        return response
    
def clean_address(request):
    user = request.user
    data = UserBase.objects.get(pk=user.id)
    profile = CleanForm(instance=data)

    event = "Clean Address"

    context={
        'event': event,
        'profile': profile
    }

    return render(request, 'accounts/user/clean_user.html',context)

def addressFormStela(request):
    user = request.user
    data = UserBase.objects.get(pk=user.id)
    profile = CleanForm(instance=data)
    form = CleanForm(request.POST, request.FILES, instance=data)
        
    if form.is_valid():
            form = profile.save(commit=False)
            form.user = user
            form.save()
            form.save(using='master')

            return redirect("http://stela.localhost:8000/cart")

def password_reset(request):
    if request.method == 'POST':
        registerForm = PwdResetForm(request.POST)
        if registerForm.is_valid():
            data = registerForm.cleaned_data['email']
            user_email = UserBase.objects.filter(email=data)
            if user_email.exists():
                for user in user_email:

                    current_site = get_current_site(request)
                    subject = _('Password Reset')
                    html_content = render_to_string('emails/registration/password_reset_email.html', {
                                'user': user,       
                                'email': user.email,    
                                'domain': current_site.domain,
                                'uid': urlsafe_base64_encode(force_bytes(user.pk)),
                                'token': account_activation_token.make_token(user),
                                })
                    text_content = strip_tags(html_content)

                    email = EmailMultiAlternatives(
                        subject,
                        text_content,
                        settings.DEFAULT_EMAIL,
                        [user.email]
                    )
                    email.attach_alternative(html_content, "text/html")
                    email.send()

                    messages.success(request, _('We have sent recovery link.'))
                    return redirect('accounts:password_reset_done')
    else:
        registerForm = PwdResetForm()
        
    return render(request, 'accounts/user/password_reset_form.html',{'form':registerForm})

def new_password_activate(request, uidb64, token):
    try:
        uid = force_str(urlsafe_base64_decode(uidb64))
        user = UserBase.objects.get(pk=uid)
    except Exception as e:
        user = None
        print(e)

    if user is not None and account_activation_token.check_token(user, token):
        if request.method == 'POST':
            form = PwdResetConfirmForm(user, request.POST)
            if form.is_valid():
                form.save()
                messages.success(request, _("Your new password has been set."))
                return redirect('/accounts/login/')
            else:
                for error in list(form.errors.values()):
                    messages.error(request, error)

        form = PwdResetConfirmForm(user)
        return render(request, 'accounts/user/password_reset_done.html', {
            'form': form,
            'call': 'password reset granted'
            })
    else:
        messages.error(request, _("Link is expired"))

    messages.error(request, _('Something went wrong, redirecting back to account login'))
    return redirect('/accounts/login/')

def account_activate(request, uidb64, token):
    try:
        uid = force_str(urlsafe_base64_decode(uidb64))
        user = UserBase.objects.get(pk=uid)
    except:
        pass
    if user is not None and account_activation_token.check_token(user, token):
        user.is_active = True
        user.save()
        login(request, user)
        messages.success(request, 'Your account has been activated.')
        return redirect('linkzone:console')
    else:
        return render(request, 'accounts/registration/activation_invalid.html') 

@login_required
def edit_details(request):

    if request.method == 'POST':
        user_form = UserEditForm(instance=request.user, data=request.POST)

        if user_form.is_valid():
            user_form.save()
    else:
        user_form = UserEditForm(instance=request.user)
    return render(request, 'link-zone/user/profile/edit_details.html', {'user_form': user_form}) 

@login_required
def delete_user(request):
    user = UserBase.objects.get(username=request.user)
    user.is_active = False
    user.save()
    logout(request)
    return redirect('accounts:delete_confirm')

def logout_view(request):
    logout(request)
    return redirect('/accounts/login/')



from django.urls import path, re_path
from . import views
from django.contrib.auth import views as auth_views
from linkzone import stripe_webhook

app_name="linkzone"

urlpatterns = [
    #emmerutpay
    path('requests/', views.request, name="request"),
    path('login-denied/', views.loginCheckout,  name="login-check"),
    path('cart/values', views.cartValues, name="cartvalues"),
    path('billings/payments/tdd-payment/', views.intentExpress, name="stripe_express"),
    path('billing/payload/<int:reciptid>/<int:orderid>', views.billingPayLoader, name="bill_payload"),
    path('mercantil-payment/', views.mercantilPayments, name="mercantil_payment"),
    path('payment-paypal', views.paymentPaypal, name="paypal"),
    path('stripe_payment/', views.paymentStripe, name="stripe_payment"),
    path('webhook/payments/', stripe_webhook.stripePayment, name="webhook_payment"),
    path('payment/', views.paymentLoader, name="payment_loader"),

]


from django.utils.translation import gettext_lazy as _
from django import forms
from stela_control.models import (
    Contact, Addresses, City,
    Comments, ContactResponse
    )

class ContactForm(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['name'].widget.attrs.update(
            {'class': 'form-control w-100', 'placeholder': _('Your Name is?')})
        self.fields['subject'].widget.attrs.update(
            {'class': 'form-control w-100', 'placeholder': _('Subject')})
        self.fields['email'].widget.attrs.update(
            {'class': 'form-control w-100', 'placeholder': _('Place Email')})
        self.fields['message'].widget.attrs.update(
            {'class': 'form-control w-100', 'placeholder': _('Your Message')})
        self.fields['name'].label=False
        self.fields['subject'].label=False
        self.fields['email'].label=False
        self.fields['message'].label=False
        
    class Meta:
        model = Contact
        fields = '__all__'
        exclude = ['host', 'status']

class ResponseContactForm(forms.ModelForm):
    class Meta:
        model = ContactResponse
        fields = ['message']

class ResponseContactFormDisabled(forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['message'].disabled = True

    class Meta:
        model = ContactResponse
        fields = ['message']

class CommentForm(forms.ModelForm):
    class Meta:
        model = Comments
        fields = ['name','email', 'message']

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['name'].widget.attrs.update(
            {'class': 'form-control w-100', 'placeholder': _('Your Name is?')})
        self.fields['email'].widget.attrs.update(
            {'class': 'form-control w-100', 'placeholder': _('Place Email')})
        self.fields['message'].widget.attrs.update(
            {'class': 'form-control w-100', 'placeholder': _('Your Message')})
        
class AddressForm(forms.ModelForm):
    class Meta:
        model = Addresses
        fields = ['country_address','city_address','address','phone']

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['city_address'].queryset = City.objects.none()

        if 'country_address' in self.data:
            try:
                country_id = int(self.data.get('country_address'))
                self.fields['city_address'].queryset = City.objects.filter(country_id=country_id).order_by('name')
            except (ValueError, TypeError):
                pass  # invalid input from the client; ignore and fallback to empty City queryset
        elif self.instance.pk:
            self.fields['city_address'].queryset = self.instance.country_address.city_set.all()



from django import template
from django.utils import timezone
import bleach, pytz


register = template.Library()

def cash(val, precision=2):
    try:
        int_val = int(val)
    except ValueError:
        raise template.TemplateSyntaxError(
        f'Value must be an integer. {val} is not an integer')

    if int_val < 1000:
        return str(int_val)
    
    elif int_val < 1_000_000:
        return f'{ int_val/1000.0:.{precision}f}'.rstrip('0').rstrip('.') + 'k'
    else:
        return f'{int_val/1_000_000.0:.{precision}f}'.rstrip('0').rstrip('.') + 'M'

register.filter('cash', cash)

@register.simple_tag
def set(varname, value):
    return value

@register.filter
def br_only(value):
    allowed_tags = ['br']
    return bleach.clean(value, tags=allowed_tags, strip=True)

@register.filter
def convert_to_user_timezone():
    user_timezone = pytz.timezone()
    print(user_timezone)
    return timezone.localtime()